/**
 * Chart visualization. 
 * Visualize embedded chart elements using Google Visualization API.
 * 
 * @namespace Alfresco
 * @class Alfresco.ChartVisualization
 */

google.load('visualization', '1.0', {'packages':['controls']});

(function()
{
   var Dom = YAHOO.util.Dom,
       Element = YAHOO.util.Element;
       
   /**
    * ChartVisualization constructor.
    * 
    * @return {Alfresco.ChartVisualization} The new visualization instance
    * @constructor
    */
   Alfresco.ChartVisualization = function()
   {
      return this;
   };

   Alfresco.ChartVisualization.prototype =
   {
   
      // Alfresco.constants.PROXY_URI
      PROXY : "http://ocopomo.ekf.tuke.sk/visualization/DataProxy",
      
      /**
       * Renders charts.
       *
       * @method draw
       */
      draw: function ChartVisualization_draw()
      {
          var elements = Dom.getElementsByClassName("chart");
          for (i in elements)
          {
              var elm = new Element(elements[i]);
              var id = elements[i].getAttribute("id");
              var data = elm.getElementsByTagName("span")[0].getAttribute("data");

              if (data != null) {
                  (function (data, self)
                  {
                  data.containerId = id;
                  data.wrapper.containerId = id + "-wrapper";
                  var html = "<div id=\"" + id + "-wrapper\"/>";
                  if (data.controls !== undefined)
                  {
                      html = "<table><tr><td>" + html + "</td></tr>";
                      for (i in data.controls)
                      {
                          data.controls[i].containerId = id + "-control-" + i;
                          html += "<tr><td><div id=\"" + id + "-control-" + i + "\"/></tr></td>";
                      }
                      html += "</table>";
                  }
                  elements[i].innerHTML = html;
                  var query = new google.visualization.Query(data.dataSourceUrl);
                  query.setQuery(data.query);
                  query.send(function(response) {self.handleResponseAndView(response, data)});                                    
                  })(this._parse(data), this);
              }
          }
       },
      
       handleResponseAndView: function ChartVisualization_handleResponseAndView(response, data)
       {
           //alert("handler " + data.containerId + " " + data.wrapper.containerId + " " + i);
           var table = response.getDataTable();

           if (data.controls !== undefined)
           {
               var dashboard = new google.visualization.Dashboard(document.getElementById(data.containerId));
               var wrapper = new google.visualization.ChartWrapper(data.wrapper);
               for (i in data.controls)
               {
                   var control = new google.visualization.ControlWrapper(data.controls[i]);
                   dashboard.bind(control, wrapper);
               }
               dashboard.draw(table);
           } else {
               data.wrapper.dataTable = table;
               var wrapper = new google.visualization.ChartWrapper(data.wrapper);
               wrapper.draw();
           }
       },
      
      _parse: function ChartVisualization__parse(str)
      {
          str = str.replace("&quot;", "\"");
          str = str.replace("&gt;", ">");
          str = str.replace("&lt;", "<");
          return eval('(' + str + ')');
      }
   };
})();